==> onboarding-0.1.1-sources.jar: org/kie/kogito/examples/onboarding/SetupPayrollModel.java <==
package org.kie.kogito.examples.onboarding;

import java.util.Map;
import java.util.HashMap;

public class SetupPayrollModel implements org.kie.kogito.Model {

    private Long id;

    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return this.id;
    }

    @Override
    public Map<String, Object> toMap() {
        Map<String, Object> params = new HashMap();
        params.put("taxRate", this.taxRate);
        params.put("vacationDays", this.vacationDays);
        params.put("payroll", this.payroll);
        params.put("employee", this.employee);
        params.put("paymentDate", this.paymentDate);
        return params;
    }

    @Override
    public void fromMap(Map<String, Object> params) {
        fromMap(null, params);
    }

    public void fromMap(Long id, Map<String, Object> params) {
        this.id = id;
        this.taxRate = (java.lang.Double) params.get("taxRate");
        this.vacationDays = (java.lang.Integer) params.get("vacationDays");
        this.payroll = (org.kie.kogito.examples.onboarding.Payroll) params.get("payroll");
        this.employee = (org.kie.kogito.examples.onboarding.Employee) params.get("employee");
        this.paymentDate = (java.util.Date) params.get("paymentDate");
    }

    private java.lang.Double taxRate;

    public java.lang.Double getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(java.lang.Double taxRate) {
        this.taxRate = taxRate;
    }

    private java.lang.Integer vacationDays;

    public java.lang.Integer getVacationDays() {
        return vacationDays;
    }

    public void setVacationDays(java.lang.Integer vacationDays) {
        this.vacationDays = vacationDays;
    }

    private org.kie.kogito.examples.onboarding.Payroll payroll;

    public org.kie.kogito.examples.onboarding.Payroll getPayroll() {
        return payroll;
    }

    public void setPayroll(org.kie.kogito.examples.onboarding.Payroll payroll) {
        this.payroll = payroll;
    }

    private org.kie.kogito.examples.onboarding.Employee employee;

    public org.kie.kogito.examples.onboarding.Employee getEmployee() {
        return employee;
    }

    public void setEmployee(org.kie.kogito.examples.onboarding.Employee employee) {
        this.employee = employee;
    }

    private java.util.Date paymentDate;

    public java.util.Date getPaymentDate() {
        return paymentDate;
    }

    public void setPaymentDate(java.util.Date paymentDate) {
        this.paymentDate = paymentDate;
    }
}

==> onboarding-0.6.0-sources.jar: org/kie/kogito/examples/onboarding/SetupPayrollModel.java <==
package org.kie.kogito.examples.onboarding;

import java.util.Map;
import java.util.HashMap;

public class SetupPayrollModel implements org.kie.kogito.Model {

    private String id;

    public void setId(String id) {
        this.id = id;
    }

    public String getId() {
        return this.id;
    }

    @Override
    public Map<String, Object> toMap() {
        Map<String, Object> params = new HashMap();
        params.put("taxRate", this.taxRate);
        params.put("vacationDays", this.vacationDays);
        params.put("payroll", this.payroll);
        params.put("employee", this.employee);
        params.put("paymentDate", this.paymentDate);
        return params;
    }

    @Override
    public void fromMap(Map<String, Object> params) {
        fromMap(null, params);
    }

    public void fromMap(String id, Map<String, Object> params) {
        this.id = id;
        this.taxRate = (java.lang.Double) params.get("taxRate");
        this.vacationDays = (java.lang.Integer) params.get("vacationDays");
        this.payroll = (org.kie.kogito.examples.onboarding.Payroll) params.get("payroll");
        this.employee = (org.kie.kogito.examples.onboarding.Employee) params.get("employee");
        this.paymentDate = (java.util.Date) params.get("paymentDate");
    }

    private java.lang.Double taxRate;

    public java.lang.Double getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(java.lang.Double taxRate) {
        this.taxRate = taxRate;
    }

    private java.lang.Integer vacationDays;

    public java.lang.Integer getVacationDays() {
        return vacationDays;
    }

    public void setVacationDays(java.lang.Integer vacationDays) {
        this.vacationDays = vacationDays;
    }

    private org.kie.kogito.examples.onboarding.Payroll payroll;

    public org.kie.kogito.examples.onboarding.Payroll getPayroll() {
        return payroll;
    }

    public void setPayroll(org.kie.kogito.examples.onboarding.Payroll payroll) {
        this.payroll = payroll;
    }

    private org.kie.kogito.examples.onboarding.Employee employee;

    public org.kie.kogito.examples.onboarding.Employee getEmployee() {
        return employee;
    }

    public void setEmployee(org.kie.kogito.examples.onboarding.Employee employee) {
        this.employee = employee;
    }

    private java.util.Date paymentDate;

    public java.util.Date getPaymentDate() {
        return paymentDate;
    }

    public void setPaymentDate(java.util.Date paymentDate) {
        this.paymentDate = paymentDate;
    }
}
